Base Data Types
===============

Stone Soup base data types.

.. autoclass:: stonesoup.types.detection.Detection
    :noindex:

.. autoclass:: stonesoup.types.groundtruth.GroundTruthState
    :noindex:

.. autoclass:: stonesoup.types.groundtruth.GroundTruthPath
    :noindex:

.. autoclass:: stonesoup.types.hypothesis.Hypothesis
    :noindex:

.. autoclass:: stonesoup.types.metric.Metric
    :noindex:

.. autoclass:: stonesoup.types.particle.Particle
    :noindex:

.. autoclass:: stonesoup.types.prediction.Prediction
    :noindex:

.. autoclass:: stonesoup.types.sensordata.SensorData
    :noindex:

.. autoclass:: stonesoup.types.state.State
    :noindex:

.. autoclass:: stonesoup.types.track.Track
    :noindex:

.. autoclass:: stonesoup.types.update.Update
    :noindex:
